from setuptools import setup

setup(
    name='particle',
    version='0.0.0',
    description='',
    long_description='',
    url='https://github.com/scikit-hep/particle',
    author='Eduardo Rodrigues',
    author_email='eduardo.rodrigues@cern.ch',
    packages=[],
    classifiers=['Development Status :: 1 - Planning'],
)
